@@ -103,7 +103,7 @@ print_props(struct libevdev *dev)
 	for (i = 0; i <= INPUT_PROP_MAX; i++) {
 		if (libevdev_has_property(dev, i))
 			printf("  Property type %d (%s)\n", i,
-					libevdev_get_property_name(i));
+					libevdev_property_get_name(i));
 	}
 }
 
@@ -185,7 +185,7 @@ main(int argc, char **argv)
 	} while (rc == LIBEVDEV_READ_STATUS_SYNC || rc == LIBEVDEV_READ_STATUS_SUCCESS || rc == -EAGAIN);
 
 	if (rc != LIBEVDEV_READ_STATUS_SUCCESS && rc != -EAGAIN)
-		fprintf(stderr, "Failed to handle events: %s\n", strerror(rc));
+		fprintf(stderr, "Failed to handle events: %s\n", strerror(-rc));
 
 	rc = 0;
 out:
